(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 10.2' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[     46633,       1437]
NotebookOptionsPosition[     44250,       1355]
NotebookOutlinePosition[     44674,       1371]
CellTagsIndexPosition[     44631,       1368]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{
Cell[TextData[{
 StyleBox["Methoden der Bioinformatik",
  FontSize->24,
  FontWeight->"Bold"],
 StyleBox[" \n\n",
  FontSize->12],
 "Eine Einf\[UDoubleDot]hrung zur Anwendung in Biologie und Medizin\n\n2. \
Auflage",
 StyleBox["\n",
  FontSize->18,
  FontWeight->"Bold"],
 StyleBox["\n",
  FontSize->12],
 "Marc-Thorsten H\[UDoubleDot]tt",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "und",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "Manuel Dehnert\n",
 StyleBox["\n",
  FontSize->12],
 "Springer Spektrum",
 StyleBox[" ",
  FontSize->12,
  FontWeight->"Bold"],
 "2006",
 StyleBox[", ",
  FontSize->12,
  FontWeight->"Bold"],
 "2016, ISBN 978-3-662-46149-5"
}], "Subsubtitle",
 CellChangeTimes->{{3.669868691792925*^9, 3.669868786167323*^9}, {
  3.6698688284727426`*^9, 3.669868879042635*^9}, {3.6698691142260866`*^9, 
  3.6698691148331213`*^9}}],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 "-Exkurs: ",
 "Pseudoereignisse"
}], "Subtitle",
 CellChangeTimes->{3.670321495640956*^9, 3.670321893142056*^9},
 Background->RGBColor[
  0.8705882352941177, 0.00392156862745098, 0.2196078431372549]],

Cell[TextData[{
 "In diesem Kapitel wurde die Sch\[ADoubleDot]tzung unter ",
 StyleBox["a-priori",
  FontSlant->"Italic"],
 "-Annahmen am Beispiel des W\[UDoubleDot]rfels erkl\[ADoubleDot]rt und die \
Priorverteilung f\[UDoubleDot]r den Parameter ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "5"], TraditionalForm]]],
 " qualitativ angegeben (vgl. Abb. 2.7). Mithilfe von ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " wollen wir nun unterschiedliche Datens\[ADoubleDot]tze ",
 StyleBox["D",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote] erzeugen (im Sinne von Gl. (2.34)) und die resultierende \
empirische Verteilung der Wahrscheinlichkeit ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "5"], TraditionalForm]]],
 " in Form eines Histogramms in Abh\[ADoubleDot]ngigkeit von ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "0"], TraditionalForm]]],
 " und ",
 StyleBox["D",
  FontSlant->"Italic"],
 " visualisieren. Eine Realisierung des Datensatzes ",
 StyleBox["D",
  FontSlant->"Italic"],
 " erhalten wir durch die folgende Funktion:"
}], "Text",
 CellChangeTimes->{{3.6746158763010902`*^9, 3.674615885137103*^9}, 
   3.6746159439001875`*^9, {3.6746159876272516`*^9, 3.674616048341341*^9}}],

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "30", "]"}], "\[IndentingNewLine]", 
 RowBox[{"dataD", ":=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"RandomInteger", "[", 
     RowBox[{"{", 
      RowBox[{"1", ",", "6"}], "}"}], "]"}], ",", 
    RowBox[{"{", "10", "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.622878368366424*^9, 3.622878386651339*^9}, {
  3.622878420980343*^9, 3.622878473744903*^9}}],

Cell[TextData[{
 "Diese Funktion gibt zehn zuf\[ADoubleDot]llige, ganzzahlige Werte aus dem \
Intervall [1, 6] aus. Hervorzuheben ist an dieser Stelle noch, dass es sich \
bei der Definition von ",
 StyleBox["dataD",
  FontWeight->"Bold"],
 " um eine verz\[ODoubleDot]gerte Zuweisung (",
 StyleBox[":=",
  FontWeight->"Bold"],
 ") und nicht um eine einmalige Festlegung (",
 StyleBox["=",
  FontWeight->"Bold"],
 ") handelt. Ruft man die Variable nun auf, so erfolgt die Erzeugung der \
Zufallszahlen dadurch jedes Mal aufs Neue. Wir setzen daher im Folgenden bei \
jedem Aufruf dieser Variablen den Zufallszahlengenerator mit dem Befehl ",
 StyleBox["SeedRandom",
  FontWeight->"Bold"],
 " auf einen neuen Anfangswert, um diese Zuweisung f\[UDoubleDot]r das hier \
diskutierte Beispiel zu kontrollieren."
}], "Text",
 CellChangeTimes->{{3.6746161656925125`*^9, 3.674616175462527*^9}, 
   3.6746162113755784`*^9}],

Cell[CellGroupData[{

Cell[BoxData["dataD"], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "2", ",", "2", ",", "1", ",", "6", ",", "3", ",", "1", ",", "4", ",", "6", 
   ",", "4", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.677570419207263*^9}]
}, Open  ]],

Cell[TextData[{
 "In diesem Beispiel fehlt also ebenfalls die Zahl 5 in der Ausgangsmenge ",
 StyleBox["D",
  FontSlant->"Italic"],
 ". Der Datensatz ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "0"], TraditionalForm]]],
 " der Pseudoereignisse wird von uns definiert als"
}], "Text",
 CellChangeTimes->{{3.674616248407633*^9, 3.6746162888776913`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"dataD0", "=", 
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6"}], "}"}]}], 
  ";"}]], "Input"],

Cell[TextData[{
 "Wie in jeder Programmiersprache kann man das ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-fache Aneinanderh\[ADoubleDot]ngen des Datensatzes ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "0"], TraditionalForm]]],
 " nat\[UDoubleDot]rlich auf verschiedene Weise erreichen. Diese \
verschiedenen Wege einmal explizit zu diskutieren, ist sehr instruktiv, um \
das M\[ODoubleDot]glichkeitsspektrum von ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " darzustellen, aber auch, um anzudeuten, dass sich Programmieraufgaben oft \
durch \[ADoubleDot]u\[SZ]erst unterschiedliche Herangehensweisen bew\
\[ADoubleDot]ltigen lassen. Zugleich sind die damit \
gegen\[UDoubleDot]bergestellten Verfahren der Iteration im Umgang mit ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " recht weit verbreitete algorithmische Grundstrukturen.\n\n",
 StyleBox["Weg 1:",
  FontWeight->"Bold"],
 " Um ein",
 StyleBox[" n",
  FontSlant->"Italic"],
 "-faches Aneinanderh\[ADoubleDot]ngen des Datensatzes ",
 StyleBox["dataD0",
  FontWeight->"Bold"],
 " zu erreichen, kann man z.B. eine Tabelle mit fortlaufenden Zahlen als \
Indexliste erzeugen und dann \[UDoubleDot]ber den Befehl ",
 StyleBox["ReplaceAll",
  FontWeight->"Bold"],
 " (der mit ",
 StyleBox["/.",
  FontWeight->"Bold"],
 " abgek\[UDoubleDot]rzt wird) jeden Index (also jede ganze (Integer-)Zahl) \
durch ",
 StyleBox["dataD0",
  FontWeight->"Bold"],
 " ersetzen. Anwenden von ",
 StyleBox["Flatten",
  FontWeight->"Bold"],
 " \[UDoubleDot]berf\[UDoubleDot]hrt danach das Resultat in eine aus ",
 StyleBox["n",
  FontSlant->"Italic"],
 " hintereinandergesetzten ",
 StyleBox["dataD0",
  FontWeight->"Bold"],
 "-Listen bestehende Liste von Pseudoereignissen."
}], "Text",
 CellChangeTimes->{{3.6746163650538025`*^9, 3.6746163944608445`*^9}, 
   3.6746164913549857`*^9, {3.6774897503134756`*^9, 3.677489759626692*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"makePseudo", "[", "n_", "]"}], ":=", 
  RowBox[{"Flatten", "[", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{"j", ",", 
      RowBox[{"{", 
       RowBox[{"j", ",", "1", ",", "n"}], "}"}]}], "]"}], "/.", " ", 
    RowBox[{"_Integer", " ", "\[Rule]", " ", "dataD0"}]}], "]"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"makePseudo", "[", "3", "]"}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "1", ",", "2", 
   ",", "3", ",", "4", ",", "5", ",", "6", ",", "1", ",", "2", ",", "3", ",", 
   "4", ",", "5", ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{3.677570419285263*^9}]
}, Open  ]],

Cell[TextData[{
 "Der Befehl ",
 StyleBox["Join",
  FontWeight->"Bold"],
 " verkn\[UDoubleDot]pft die Datens\[ADoubleDot]tze miteinander, und die \
Wahrscheinlichkeit ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "5"], TraditionalForm]]],
 " kann f\[UDoubleDot]r den Datensatz ",
 StyleBox["D",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote] durch Nachz\[ADoubleDot]hlen berechnet werden."
}], "Text",
 CellChangeTimes->{{3.674616505843007*^9, 3.674616574170106*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{"SeedRandom", "[", "30", "]"}], "\[IndentingNewLine]", 
 RowBox[{"dataDprime", "=", 
  RowBox[{"Join", "[", 
   RowBox[{
    RowBox[{"makePseudo", "[", "1", "]"}], ",", "dataD"}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.622878554057192*^9, 3.6228785541052847`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "2", ",", "2", 
   ",", "1", ",", "6", ",", "3", ",", "1", ",", "4", ",", "6", ",", "4", ",", 
   "2"}], "}"}]], "Output",
 CellChangeTimes->{3.6775704193008633`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"probP5", "=", 
  RowBox[{
   RowBox[{"Count", "[", 
    RowBox[{"dataDprime", ",", "5"}], "]"}], "/", 
   RowBox[{"Length", "[", "dataDprime", "]"}]}]}]], "Input"],

Cell[BoxData[
 FractionBox["1", "16"]], "Output",
 CellChangeTimes->{3.6775704193164635`*^9}]
}, Open  ]],

Cell[TextData[{
 "F\[UDoubleDot]r diese konkrete Realisierung von ",
 StyleBox["D",
  FontSlant->"Italic"],
 "\[CloseCurlyQuote] wird ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "5"], TraditionalForm]]],
 " also als 1/16 gesch\[ADoubleDot]tzt.\n\n",
 StyleBox["Weg 2:",
  FontWeight->"Bold"],
 " Durch eine ",
 StyleBox["Do",
  FontWeight->"Bold"],
 "-Schleife wird in jedem Durchgang ein Datensatz angeh\[ADoubleDot]ngt."
}], "Text",
 CellChangeTimes->{{3.6746165905631304`*^9, 3.6746166373711977`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"tmp1", "=", "dataD0"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"Do", "[", 
  RowBox[{
   RowBox[{"tmp1", "=", 
    RowBox[{"Join", "[", 
     RowBox[{"tmp1", ",", "dataD0"}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{"j", ",", "1", ",", "3"}], "}"}]}], 
  "]"}], "\[IndentingNewLine]", "tmp1"}], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "1", ",", "2", 
   ",", "3", ",", "4", ",", "5", ",", "6", ",", "1", ",", "2", ",", "3", ",", 
   "4", ",", "5", ",", "6", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", 
   ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{3.677570419332063*^9}]
}, Open  ]],

Cell[TextData[{
 StyleBox["Weg 3:",
  FontWeight->"Bold"],
 " Mit dem Befehl ",
 StyleBox["Nest[f, x, n]",
  FontWeight->"Bold"],
 " kann man die Funktion ",
 StyleBox["f",
  FontSlant->"Italic"],
 " sehr einfach ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-mal auf ",
 StyleBox["x",
  FontSlant->"Italic"],
 " schachteln. ",
 StyleBox["Nest[f, x, 3]",
  FontWeight->"Bold"],
 " ergibt also ",
 StyleBox["f ( f ( f (x)))",
  FontSlant->"Italic"],
 ". Hat die Funktion ",
 StyleBox["f",
  FontSlant->"Italic"],
 " mehrere Argumente, muss man mit dem ",
 StyleBox["slot",
  FontSlant->"Italic"],
 "-Zeichen ",
 StyleBox["#",
  FontWeight->"Bold"],
 " die Stelle benennen, die geschachtelt wird. Damit das Objekt dann noch als \
Funktion erkannt wird, muss man hinter den ",
 StyleBox["f",
  FontSlant->"Italic"],
 "-Ausdruck (also vor das erste Komma) das ",
 StyleBox["function",
  FontSlant->"Italic"],
 "-Zeichen ",
 StyleBox["&",
  FontWeight->"Bold"],
 " setzen. F\[UDoubleDot]r eine Funktion ",
 StyleBox["f (x, y)",
  FontSlant->"Italic"],
 " ergibt ",
 StyleBox["Nest[f(#, y)&, x, 3]",
  FontWeight->"Bold"],
 " also gerade ",
 StyleBox["f ( f ( f (x, y), y), y)",
  FontSlant->"Italic"],
 ". \n\nTr\[ADoubleDot]gt man f\[UDoubleDot]r ",
 StyleBox["f(x, #)",
  FontWeight->"Bold"],
 " nun ",
 StyleBox["Join[dataD0, #]",
  FontWeight->"Bold"],
 " ein, so erh\[ADoubleDot]lt man die ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-fach hintereinandergeh\[ADoubleDot]ngte Liste von Pseudoereignissen."
}], "Text",
 CellChangeTimes->{{3.674616701961292*^9, 3.6746167065552983`*^9}, 
   3.674616743998353*^9, {3.6746168820085516`*^9, 3.67461689452757*^9}, 
   3.67461696416467*^9, {3.674616998141719*^9, 3.674616999253721*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"tmp2", "=", 
  RowBox[{"Nest", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Join", "[", 
      RowBox[{"dataD0", ",", "#"}], "]"}], "&"}], ",", "dataD0", ",", "3"}], 
   "]"}]}]], "Input"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "1", ",", "2", ",", "3", ",", "4", ",", "5", ",", "6", ",", "1", ",", "2", 
   ",", "3", ",", "4", ",", "5", ",", "6", ",", "1", ",", "2", ",", "3", ",", 
   "4", ",", "5", ",", "6", ",", "1", ",", "2", ",", "3", ",", "4", ",", "5", 
   ",", "6"}], "}"}]], "Output",
 CellChangeTimes->{3.677570419363263*^9}]
}, Open  ]],

Cell[TextData[{
 "Nun gehen wir zur Verteilung ",
 StyleBox["P(",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "5"], TraditionalForm]],
  FontSize->13,
  FontSlant->"Italic"],
 StyleBox[")",
  FontSlant->"Italic"],
 " \[UDoubleDot]ber, indem wir mehrere Datens\[ADoubleDot]tze ",
 StyleBox["D",
  FontSlant->"Italic"],
 " erzeugen und die relative H\[ADoubleDot]ufigkeit f\[UDoubleDot]r das \
Auftreten der Zahl 5 berechnen. Die Menge an Pseudodaten ",
 Cell[BoxData[
  FormBox[
   SubsuperscriptBox["D", "0", "n"], TraditionalForm]],
  FormatType->"TraditionalForm"],
 " wird mit ",
 StyleBox["n",
  FontSlant->"Italic"],
 " variiert. F\[UDoubleDot]r ",
 StyleBox["n = 0",
  FontSlant->"Italic"],
 ", d.h. ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["D", "0"], TraditionalForm]]],
 " = { }, liefert die Funktion"
}], "Text",
 CellChangeTimes->{{3.674617058752808*^9, 3.6746170831808443`*^9}, {
  3.6746171244079037`*^9, 3.6746171392469254`*^9}, {3.67461717037097*^9, 
  3.674617189966998*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "30", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"probP5", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"makePseudo", "[", "0", "]"}], ",", "dataD"}], "]"}], ",", 
       "5"}], "]"}], "/", 
     RowBox[{"Length", "[", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"makePseudo", "[", "0", "]"}], ",", "dataD"}], "]"}], "]"}]}],
     ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.622878604233139*^9, 3.6228786042797956`*^9}}],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", 
   FractionBox["1", "5"], ",", 
   FractionBox["1", "5"], ",", "0", ",", 
   FractionBox["2", "5"], ",", 
   FractionBox["1", "5"], ",", 
   FractionBox["1", "10"], ",", 
   FractionBox["1", "10"], ",", 
   FractionBox["3", "10"], ",", 
   FractionBox["1", "5"]}], "}"}]], "Output",
 CellChangeTimes->{3.6775704193788633`*^9}]
}, Open  ]],

Cell[TextData[{
 "die jeweilige Wahrscheinlichkeit ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "5"], TraditionalForm]]],
 " f\[UDoubleDot]r zehn unterschiedliche Realisierungen von ",
 StyleBox["D",
  FontSlant->"Italic"],
 " in Form einer Liste. Die Visualisierung der empirischen Verteilung ist \
durch die Funktion ",
 StyleBox["Histogram",
  FontWeight->"Bold"],
 " m\[ODoubleDot]glich."
}], "Text",
 CellChangeTimes->{{3.67461726600711*^9, 3.6746173082881727`*^9}, 
   3.6746173474262285`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  StyleBox["pln0",
   FontColor->GrayLevel[0]], 
  StyleBox["=",
   FontColor->GrayLevel[0]], 
  RowBox[{"Histogram", "[", 
   RowBox[{"probP5", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0.05"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.568708231578125*^9, 3.5687082476875*^9}, {
  3.6228786496254*^9, 3.6228786802840147`*^9}, {3.6774901788754325`*^9, 
  3.6774901816688375`*^9}}],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.5459999999999999], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.5459999999999999], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0., 0}, {0.05, 2}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{15.200980392156865`, 
          31.828431372549023`}, {-6.8090391300670206`, 90.24930417967833}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.1, 0}, {0.15000000000000002`, 2}, "RoundingRadius" -> 
           0]},
         ImageSizeCache->{{47.45588235294118, 
          64.08333333333334}, {-6.8090391300670206`, 90.24930417967833}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.2, 0}, {0.25, 4}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{79.7107843137255, 
          96.33823529411765}, {-103.36738243981237`, 90.24930417967833}}],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.30000000000000004`, 0}, {0.35000000000000003`, 1}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{111.96568627450982`, 128.593137254902}, {
          41.470132524805656`, 90.24930417967833}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.4, 0}, {0.45, 1}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{144.22058823529414`, 160.8480392156863}, {
          41.470132524805656`, 90.24930417967833}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.02, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0., 1.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677570421360067*^9}]
}, Open  ]],

Cell[TextData[{
 "Abbildung 2.10 zeigt die Histogramme f\[UDoubleDot]r a: ",
 StyleBox["n",
  FontSlant->"Italic"],
 " = 0, b: ",
 StyleBox["n",
  FontSlant->"Italic"],
 " = 1 und c: ",
 StyleBox["n",
  FontSlant->"Italic"],
 " = 10. Man erkennt deutlich den bereits in der schematischen Darstellung, \
Abb. 2.7, angedeuteten Effekt: Mit wachsender Zahl der Pseudoereignisse \
entsteht eine immer schmalere Verteilung um den Wert ",
 StyleBox["p",
  FontSlant->"Italic"],
 " = 1/6."
}], "Text",
 CellChangeTimes->{{3.677489904087946*^9, 3.677489920140374*^9}, 
   3.6774899507184277`*^9, 3.677489982928286*^9}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "30", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "1"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"probP5", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"makePseudo", "[", "n", "]"}], ",", "dataD"}], "]"}], ",", 
       "5"}], "]"}], "/", 
     RowBox[{"Length", "[", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"makePseudo", "[", "n", "]"}], ",", "dataD"}], "]"}], "]"}]}],
     ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{{3.622878764527165*^9, 3.622878764590308*^9}, {
  3.6774900971730886`*^9, 3.6774900975942893`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "16"], ",", 
   FractionBox["3", "16"], ",", 
   FractionBox["3", "16"], ",", 
   FractionBox["1", "16"], ",", 
   FractionBox["5", "16"], ",", 
   FractionBox["3", "16"], ",", 
   FractionBox["1", "8"], ",", 
   FractionBox["1", "8"], ",", 
   FractionBox["1", "4"], ",", 
   FractionBox["3", "16"]}], "}"}]], "Output",
 CellChangeTimes->{3.6775704219684677`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pln1", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"probP5", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0.05"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.633034257494918*^9, 3.6330342612291317`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.5459999999999999], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.5459999999999999], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.05, 0}, {0.1, 2}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{31.328431372549023`, 
          47.95588235294118}, {-6.8090391300670206`, 90.24930417967833}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.1, 0}, {0.15000000000000002`, 2}, "RoundingRadius" -> 
           0]},
         ImageSizeCache->{{47.45588235294118, 
          64.08333333333334}, {-6.8090391300670206`, 90.24930417967833}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.15000000000000002`, 0}, {0.2, 4}, "RoundingRadius" -> 
           0]},
         ImageSizeCache->{{63.58333333333334, 
          80.2107843137255}, {-103.36738243981237`, 90.24930417967833}}],
        StatusArea[#, 4]& ,
        TagBoxNote->"4"],
       StyleBox["4", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[4, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.25, 0}, {0.30000000000000004`, 1}, "RoundingRadius" -> 
           0]},
         ImageSizeCache->{{95.83823529411765, 112.46568627450982`}, {
          41.470132524805656`, 90.24930417967833}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.30000000000000004`, 0}, {0.35000000000000003`, 1}, 
           "RoundingRadius" -> 0]},
         ImageSizeCache->{{111.96568627450982`, 128.593137254902}, {
          41.470132524805656`, 90.24930417967833}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{-0.02, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0., 1.}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.6775704220152683`*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"SeedRandom", "[", "30", "]"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"n", "=", "10"}], ";"}], "\[IndentingNewLine]", 
 RowBox[{"probP5", "=", 
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Count", "[", 
      RowBox[{
       RowBox[{"Join", "[", 
        RowBox[{
         RowBox[{"makePseudo", "[", "n", "]"}], ",", "dataD"}], "]"}], ",", 
       "5"}], "]"}], "/", 
     RowBox[{"Length", "[", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"makePseudo", "[", "n", "]"}], ",", "dataD"}], "]"}], "]"}]}],
     ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", "1", ",", "10"}], "}"}]}], "]"}]}]}], "Input",
 CellChangeTimes->{
  3.6228787761068163`*^9, {3.6774901036959*^9, 3.6774901040235004`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   FractionBox["1", "7"], ",", 
   FractionBox["6", "35"], ",", 
   FractionBox["6", "35"], ",", 
   FractionBox["1", "7"], ",", 
   FractionBox["1", "5"], ",", 
   FractionBox["6", "35"], ",", 
   FractionBox["11", "70"], ",", 
   FractionBox["11", "70"], ",", 
   FractionBox["13", "70"], ",", 
   FractionBox["6", "35"]}], "}"}]], "Output",
 CellChangeTimes->{3.677570422030868*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"pln10", "=", 
  RowBox[{"Histogram", "[", 
   RowBox[{"probP5", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "1", ",", "0.05"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"0", ",", "0.6"}], "}"}], ",", "All"}], "}"}]}], ",", 
    RowBox[{"AxesOrigin", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "0"}], "}"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.570608743839223*^9, 3.570608861229097*^9}, {
  3.6330341989779468`*^9, 3.6330342034492025`*^9}, {3.6330342666864433`*^9, 
  3.6330342698156223`*^9}},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{
   {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
    Opacity[0.602], Thickness[Small]}], {}, 
    {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], EdgeForm[{
     Opacity[0.602], Thickness[Small]}], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.1, 0}, {0.15000000000000002`, 2}, "RoundingRadius" -> 
           0]},
         ImageSizeCache->{{63.58333333333333, 91.5}, {36.53957016273469, 
          93.31929026327198}}],
        StatusArea[#, 2]& ,
        TagBoxNote->"2"],
       StyleBox["2", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[2, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          
          RectangleBox[{0.15000000000000002`, 0}, {0.2, 7}, "RoundingRadius" -> 
           0]},
         ImageSizeCache->{{91., 118.91666666666666`}, {-104.15973008860853`, 
          93.31929026327198}}],
        StatusArea[#, 7]& ,
        TagBoxNote->"7"],
       StyleBox["7", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[7, {}], "Tooltip"]& ], 
     TagBox[
      TooltipBox[
       TagBox[
        DynamicBox[{
          FEPrivate`If[
           CurrentValue["MouseOver"], 
           EdgeForm[{
             GrayLevel[0.5], 
             AbsoluteThickness[1.5], 
             Opacity[0.66]}], {}, {}], 
          RectangleBox[{0.2, 0}, {0.25, 1}, "RoundingRadius" -> 0]},
         ImageSizeCache->{{118.41666666666666`, 146.33333333333331`}, {
          64.67943021300334, 93.31929026327198}}],
        StatusArea[#, 1]& ,
        TagBoxNote->"1"],
       StyleBox["1", {}, StripOnInput -> False]],
      Annotation[#, 
       Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  PlotRange->{{0, 0.6}, {All, All}},
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.677570422093268*^9}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GraphicsGrid", "[", 
  RowBox[{"{", 
   RowBox[{"{", 
    RowBox[{"pln0", ",", "pln1", ",", "pln10"}], "}"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.61916939911263*^9, 3.6191694825234003`*^9}, {
   3.6191699861892085`*^9, 3.619169987507284*^9}, {3.6191701237470765`*^9, 
   3.619170124018092*^9}, {3.619170201370516*^9, 3.6191702035166388`*^9}, {
   3.6191704440493965`*^9, 3.619170449415704*^9}, {3.6330342783131084`*^9, 
   3.6330343051486435`*^9}, 3.677556187549583*^9},
 FontColor->GrayLevel[0],
 Background->RGBColor[0.87, 0.94, 1]],

Cell[BoxData[
 GraphicsBox[{{}, {InsetBox[
     GraphicsBox[{
       {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
        EdgeForm[{Opacity[0.5459999999999999], Thickness[Small]}], {}, 
        {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
         EdgeForm[{Opacity[0.5459999999999999], Thickness[Small]}], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              RectangleBox[{0., 0}, {0.05, 2}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{18.595816355861416`, 
              22.794332017637785`}, {-39.60623125189069, -16.96246250378138}}],
            StatusArea[#, 2]& ,
            TagBoxNote->"2"],
           StyleBox["2", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[2, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.1, 0}, {0.15000000000000002`, 2}, 
               "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{25.992847679414155`, 
              30.191363341190524`}, {-39.60623125189069, -16.96246250378138}}],
            StatusArea[#, 2]& ,
            TagBoxNote->"2"],
           StyleBox["2", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[2, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              RectangleBox[{0.2, 0}, {0.25, 4}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{33.38987900296689, 
              37.58839466474326}, {-61.74999999999999, -16.96246250378138}}],
            StatusArea[#, 4]& ,
            TagBoxNote->"4"],
           StyleBox["4", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[4, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.30000000000000004`, 0}, {
               0.35000000000000003`, 1}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{40.786910326519646`, 
              44.985425988296}, {-28.53434687783603, -16.96246250378138}}],
            StatusArea[#, 1]& ,
            TagBoxNote->"1"],
           StyleBox["1", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[1, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              RectangleBox[{0.4, 0}, {0.45, 1}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{48.183941650072384`, 
              52.38245731184874}, {-28.53434687783603, -16.96246250378138}}],
            StatusArea[#, 1]& ,
            TagBoxNote->"1"],
           StyleBox["1", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{-0.02, 0},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      PlotRange->{{0., 1.}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {193.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{
       {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
        EdgeForm[{Opacity[0.5459999999999999], Thickness[Small]}], {}, 
        {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
         EdgeForm[{Opacity[0.5459999999999999], Thickness[Small]}], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              RectangleBox[{0.05, 0}, {0.1, 2}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{22.294332017637785`, 
              26.492847679414155`}, {-39.60623125189069, -16.96246250378138}}],
            StatusArea[#, 2]& ,
            TagBoxNote->"2"],
           StyleBox["2", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[2, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.1, 0}, {0.15000000000000002`, 2}, 
               "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{25.992847679414155`, 
              30.191363341190527`}, {-39.60623125189069, -16.96246250378138}}],
            StatusArea[#, 2]& ,
            TagBoxNote->"2"],
           StyleBox["2", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[2, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.15000000000000002`, 0}, {0.2, 4}, 
               "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{29.691363341190527`, 
              33.88987900296689}, {-61.74999999999999, -16.96246250378138}}],
            StatusArea[#, 4]& ,
            TagBoxNote->"4"],
           StyleBox["4", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[4, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.25, 0}, {0.30000000000000004`, 1}, 
               "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{37.08839466474326, 
              41.28691032651964}, {-28.53434687783603, -16.96246250378138}}],
            StatusArea[#, 1]& ,
            TagBoxNote->"1"],
           StyleBox["1", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[1, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.30000000000000004`, 0}, {
               0.35000000000000003`, 1}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{40.78691032651964, 
              44.98542598829601}, {-28.53434687783603, -16.96246250378138}}],
            StatusArea[#, 1]& ,
            TagBoxNote->"1"],
           StyleBox["1", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{-0.02, 0},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      PlotRange->{{0., 1.}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {580.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}], InsetBox[
     GraphicsBox[{
       {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
        EdgeForm[{Opacity[0.602], Thickness[Small]}], {}, 
        {RGBColor[0.987148, 0.8073604000000001, 0.49470040000000004`], 
         EdgeForm[{Opacity[0.602], Thickness[Small]}], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.1, 0}, {0.15000000000000002`, 2}, 
               "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{30.18449876276071, 
              36.84869153238802}, {-30.116044645558148`, \
-16.962462503781396`}}],
            StatusArea[#, 2]& ,
            TagBoxNote->"2"],
           StyleBox["2", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[2, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              
              RectangleBox[{0.15000000000000002`, 0}, {0.2, 7}, 
               "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{36.34869153238802, 
              43.012884302015294`}, {-61.75000000000001, \
-16.962462503781396`}}],
            StatusArea[#, 7]& ,
            TagBoxNote->"7"],
           StyleBox["7", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[7, {}], "Tooltip"]& ], 
         TagBox[
          TooltipBox[
           TagBox[
            DynamicBox[{
              FEPrivate`If[
               CurrentValue["MouseOver"], 
               EdgeForm[{
                 GrayLevel[0.5], 
                 AbsoluteThickness[1.5], 
                 Opacity[0.66]}], {}, {}], 
              RectangleBox[{0.2, 0}, {0.25, 1}, "RoundingRadius" -> 0]},
             
             ImageSizeCache->{{42.512884302015294`, 
              49.17707707164257}, {-23.78925357466977, -16.962462503781396`}}],
            StatusArea[#, 1]& ,
            TagBoxNote->"1"],
           StyleBox["1", {}, StripOnInput -> False]],
          Annotation[#, 
           Style[1, {}], "Tooltip"]& ]}, {}, {}}, {{}, {}, {}}},
      AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
      Axes->{True, True},
      AxesLabel->{None, None},
      AxesOrigin->{0, 0},
      FrameLabel->{{None, None}, {None, None}},
      FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
      GridLines->{None, None},
      GridLinesStyle->Directive[
        GrayLevel[0.5, 0.4]],
      PlotRange->{{0, 0.6}, {All, All}},
      PlotRangePadding->{{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.02], 
         Scaled[0.05]}},
      Ticks->{Automatic, Automatic}], {967.5, -116.80842387373012`}, 
     ImageScaled[{0.5, 0.5}], {360., 222.49223594996212`}]}, {}},
  ContentSelectable->True,
  PlotRangePadding->{6, 5}]], "Output",
 CellChangeTimes->{3.6775704221556683`*^9}]
}, Open  ]]
}, Open  ]]
},
WindowSize->{507, 900},
WindowMargins->{{1018, Automatic}, {213, Automatic}},
PrivateNotebookOptions->{"VersionedStylesheet"->{"Default.nb"[8.] -> False}},
FrontEndVersion->"10.4 for Microsoft Windows (64-bit) (April 11, 2016)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[558, 20, 870, 36, 182, "Subsubtitle"],
Cell[CellGroupData[{
Cell[1453, 60, 265, 8, 66, "Subtitle"],
Cell[1721, 70, 1211, 33, 182, "Text"],
Cell[2935, 105, 413, 10, 52, "Input"],
Cell[3351, 117, 913, 21, 201, "Text"],
Cell[CellGroupData[{
Cell[4289, 142, 31, 0, 31, "Input"],
Cell[4323, 144, 202, 5, 31, "Output"]
}, Open  ]],
Cell[4540, 152, 357, 10, 68, "Text"],
Cell[4900, 164, 164, 5, 31, "Input"],
Cell[5067, 171, 1888, 51, 391, "Text"],
Cell[6958, 224, 330, 9, 52, "Input"],
Cell[CellGroupData[{
Cell[7313, 237, 63, 1, 31, "Input"],
Cell[7379, 240, 286, 6, 31, "Output"]
}, Open  ]],
Cell[7680, 249, 469, 14, 68, "Text"],
Cell[CellGroupData[{
Cell[8174, 267, 291, 6, 52, "Input"],
Cell[8468, 275, 268, 6, 31, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[8773, 286, 187, 5, 31, "Input"],
Cell[8963, 293, 93, 2, 46, "Output"]
}, Open  ]],
Cell[9071, 298, 510, 16, 106, "Text"],
Cell[CellGroupData[{
Cell[9606, 318, 343, 10, 72, "Input"],
Cell[9952, 330, 350, 7, 52, "Output"]
}, Open  ]],
Cell[10317, 340, 1726, 62, 239, "Text"],
Cell[CellGroupData[{
Cell[12068, 406, 212, 7, 31, "Input"],
Cell[12283, 415, 350, 7, 52, "Output"]
}, Open  ]],
Cell[12648, 425, 1021, 34, 108, "Text"],
Cell[CellGroupData[{
Cell[13694, 463, 684, 20, 112, "Input"],
Cell[14381, 485, 376, 11, 46, "Output"]
}, Open  ]],
Cell[14772, 499, 504, 15, 87, "Text"],
Cell[CellGroupData[{
Cell[15301, 518, 429, 12, 31, "Input"],
Cell[15733, 532, 4047, 116, 236, "Output"]
}, Open  ]],
Cell[19795, 651, 610, 18, 106, "Text"],
Cell[CellGroupData[{
Cell[20430, 673, 867, 25, 148, "Input"],
Cell[21300, 700, 424, 13, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[21761, 718, 313, 8, 47, "Input"],
Cell[22077, 728, 4127, 120, 236, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[26241, 853, 842, 25, 148, "Input"],
Cell[27086, 880, 425, 13, 46, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[27548, 898, 684, 18, 88, "Input"],
Cell[28235, 918, 2736, 80, 240, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[31008, 1003, 568, 11, 47, "Input"],
Cell[31579, 1016, 12643, 335, 123, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)

